<?php

/**
 * @file
 * Define the deriver for REST Easy OpenAPI generators.
 */

namespace Drupal\rest_easy\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\rest_easy\Plugin\APIManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class RESTEasyApiDeriver
 *
 * @package Drupal\rest_easy\Plugin\Derivative
 */
class RESTEasyApiDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * @var \Drupal\rest_easy\Plugin\APIManager
   *   The API plugin manager
   */
  protected APIManager $api_manager;

  /**
   * RESTEasyApiDeriver constructor.
   *
   * @param \Drupal\rest_easy\Plugin\APIManager $api_manager
   */
  public function __construct(APIManager $api_manager) {
    $this->api_manager = $api_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('plugin.manager.rest_easy.api')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    foreach ($this->api_manager->getDefinitions() as $plugin_id => $api_plugin) {
      $this->derivatives[$plugin_id] = $base_plugin_definition;
      $this->derivatives[$plugin_id]['id'] = $plugin_id;
      $this->derivatives[$plugin_id]['label'] = $api_plugin['label'];
    }
    return $this->derivatives;
  }
}
