<?php

/**
 * @file
 * Create routes for endpoint plugins.
 */

namespace Drupal\rest_easy\Routing;

use Drupal\Core\Logger\LoggerChannelFactory;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\rest_easy\Plugin\APIManager;

/**
 * Class EndpointRouteBuilder
 *
 * @package Drupal\rest_easy\Routing
 */
class APIRouteBuilder {

  use StringTranslationTrait;

  /**
   * @var \Drupal\rest_easy\Plugin\APIManager
   *    API plugin manager
   */
  protected APIManager $api_manager;

  /**
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   *   Logger service
   */
  protected \Drupal\Core\Logger\LoggerChannelInterface $logger;

  /**
   * EndpointRouteBuilder constructor.
   *
   */
  public function __construct(LoggerChannelFactory $logger_factory, APIManager $api_manager) {
    $this->api_manager = $api_manager;
    $this->logger = $logger_factory->get('rest_easy');
  }

  /**
   * Create routes for every endpoint plugin.
   *
   * @return array
   */
  public function routes(): array {
    $routes = [];
    foreach ($this->api_manager->getDefinitions() as $plugin_id => $plugin_definition) {
      try {
        $api_plugin = $this->api_manager->createInstance($plugin_id);
        $routes = array_merge($routes, $api_plugin->routes());
      } catch (\Exception $exception) {
        $this->logger->error($this->t('Unable to generate routes for REST Easy API plugin "@plugin_id: @message', [
          '@message' => $exception->getMessage(),
          '@plugin_id' => $plugin_id,
        ]));
      }
    }
    return $routes;
  }
}
